import React from "react";
export interface TienStickyProps {
    /**
     * Do not recommend using `id` attribute. Should use only to change background, padding, color of sticky.
     * The [HTML `id`][1] attribute. This set the value of element's id
     * content attribute.
     *
     * [1]: https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/id
     */
    id?: string;
    children?: React.ReactNode;
    /**
     * Place sticky in top-left/top-right/bottom-left/bottom-right. Default is "bottom-right"
     */
    stickyPosition?: "top-left" | "top-right" | "bottom-left" | "bottom-right";
    /**
     * Visible value of sticky in controlled mode.
     */
    isShowSticky?: boolean;
    /**
     * Decide if the sticky will expand or not in a controlled mode.
     */
    isExpandSticky?: boolean;
    /**
     * Set width of the sticky using CSS width. Default width is 300px.
     */
    stickyWidth?: number | string;
    /**
     * Set height of the sticky using CSS height. Default height is 200px.
     */
    stickyHeight?: number | string;
    /**
     * Set width of the expanded sticky using CSS width. Default expanded width is 400px.
     */
    expandStickyWidth?: number | string;
    /**
     * Set height of the expanded sticky using CSS height. Default expanded height is 300px.
     */
    expandStickyHeight?: number | string;
    /**
     * Set the header of the sticky. You can use HTML elements to display some buttons that can close or expand the sticky.
     */
    headerSticky?: React.ReactNode;
    /**
     * Do not recommend using `className` attribute. Should use only to change background, padding, color of sticky.
     * The [HTML `className`][1] attribute. This set the value of element's class
     * content attribute.
     *
     * [1]: https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/class  */
    className?: string;
    /**
     * Do not recommend using `style` attribute. Should use only to change background, padding, color of sticky.
     * The [ReactJS `style`][1] attribute. This set the value of element's style
     * content attribute.
     *
     * [1]: https://reactjs.org/docs/dom-elements.html#style */
    style?: React.CSSProperties;
}
export declare const TienSticky: React.ForwardRefExoticComponent<TienStickyProps & React.RefAttributes<React.ReactNode>>;
